@@ -131,13 +131,12 @@ check_params = function(params_sleep = c(), params_metrics = c(),
       " Note that this option will be deprecated in the next CRAN release."))
     }
   }
-  if (length(params_metrics) > 0 & length(params_sleep) > 0) {
-    if (length(params_sleep[["def.noc.sleep"]]) != 2) {
-      if (params_sleep[["HASPT.algo"]] != "HorAngle") {
-        params_sleep[["HASPT.algo"]] = "HDCZA"
-      }
-    } else if (length(params_sleep[["def.noc.sleep"]]) == 2) {
-      params_sleep[["HASPT.algo"]] = "notused"
+  if (length(params_metrics) > 0) {
+    if (params_metrics[["do.brondcounts"]] == TRUE) {
+      stop(paste0("\nThe brondcounts option has been deprecated following issues with the ",
+                  "activityCounts package. We will reinsert brondcounts ",
+                  "once the issues are resolved. Consider using argument do.neishabouricounts, ",
+                  "for more information see package documentation."), call. = FALSE)
     }
     if (params_metrics[["do.neishabouricounts"]] == TRUE) {
       if ("actilifecounts" %in% rownames(utils::installed.packages()) == FALSE) {
@@ -148,6 +147,16 @@ check_params = function(params_sleep = c(), params_metrics = c(),
         }
       }
     }
+  }
+  
+  if (length(params_metrics) > 0 & length(params_sleep) > 0) {
+    if (length(params_sleep[["def.noc.sleep"]]) != 2) {
+      if (params_sleep[["HASPT.algo"]] != "HorAngle") {
+        params_sleep[["HASPT.algo"]] = "HDCZA"
+      }
+    } else if (length(params_sleep[["def.noc.sleep"]]) == 2) {
+      params_sleep[["HASPT.algo"]] = "notused"
+    }
     if (params_general[["sensor.location"]] == "hip" &  params_sleep[["HASPT.algo"]] != "notused") {
       if (params_metrics[["do.anglex"]] == FALSE | params_metrics[["do.angley"]] == FALSE | params_metrics[["do.anglez"]] == FALSE) {
         warning(paste0("\nWhen working with hip data all three angle metrics are needed,",
