@@ -451,7 +451,7 @@ g.part1 = function(datadir = c(), outputdir = c(), f0 = 1, f1 = c(),
       # packages2passon = 'Rcpp'
       functions2passon = c("g.inspectfile", "g.calibrate","g.getmeta", "g.dotorcomma", "g.applymetrics",
                            "g.readaccfile", "g.wavread", "g.downsample", "updateBlocksize",
-                           "g.getstarttime", "POSIXtime2iso8601", "chartime2iso8601",
+                           "g.getstarttime", "POSIXtime2iso8601",
                            "iso8601chartime2POSIX", "datadir2fnames", "read.myacc.csv",
                            "get_nw_clip_block_params", "get_starttime_weekday_meantemp_truncdata", "ismovisens",
                            "g.extractheadervars", "g.imputeTimegaps", "parseGT3Xggir")
