@@ -192,16 +192,16 @@ g.plot5 = function(metadatadir=c(),dofirstpage=FALSE, viewingwindow = 1,f0=c(),f
           # not sure why I had to change x to 0 (from 1) in the following line:
           text(x=0,y=(max(YXLIM)*0.95),labels=vars[3],pos=4,font=2,cex=1.2)
           #Sleep efficiency
-          YXLIM = c(0,120)
+          YXLIM = c(0, 120)
           B5 = barplot(as.matrix(f06),names.arg=days_SLEEP,beside=TRUE,#axes=FALSE,
                        ylim=YXLIM,cex.names=CEXN,las=0,col=CLS_B,density = 20) #,density = 20
-          abline(h=60,lty=2,lwd=2)
-          abline(h=100,lty=3,lwd=1)
-          topp = mean(as.matrix(round(f06)))*0.1
-          text(y= as.matrix(round(f06))+topp, x= B5, labels=as.character(as.matrix(round(f06))), xpd=TRUE,cex=1)
-          text(x=1,y=(max(YXLIM)-10),labels=vars[4],pos=4,font=2,cex=1.2)
+          abline(h = 60, lty = 2, lwd = 2)
+          abline(h = 100,lty = 3, lwd = 1)
+          topp = mean(as.matrix(round(f06))) * 0.1
+          text(y = as.matrix(round(f06)) + topp, x = B5, labels = as.character(as.matrix(round(f06))), xpd = TRUE,cex = 1)
+          text(x = 1, y = (max(YXLIM) - 10), labels = vars[4], pos = 4, font = 2, cex = 1.2)
           #-----------------------------------------------------------------------------------
-          mtext(paste("Activity and sleep report: ",fnamesmeta[i],sep=""), side = 3, line = 0, outer = TRUE,font=2,cex=0.7)
+          mtext(paste("Activity and sleep report: ",fnamesmeta[i], sep = ""), side = 3, line = 0, outer = TRUE,font=2,cex=0.7)
         }
         LWDX = 2.5 #linewidth for coloured lines
         LWDA = 0.2
@@ -214,8 +214,8 @@ g.plot5 = function(metadatadir=c(),dofirstpage=FALSE, viewingwindow = 1,f0=c(),f
         time =  as.character(M$metashort[,1])
         nw_time = as.character(M$metalong[,1])
         if (length(unlist(strsplit(time[1],"T"))) > 1) { # ISO timestamp format
-          time = as.character(iso8601chartime2POSIX(time,desiredtz))
-          nw_time = as.character(iso8601chartime2POSIX(nw_time,desiredtz))
+          time = format(iso8601chartime2POSIX(time,desiredtz))
+          nw_time = format(iso8601chartime2POSIX(nw_time,desiredtz))
         }
         time_unclassed = unclass(as.POSIXlt(time,desiredtz)) # Updated by by VvH: now doing this step once, and re-using the output
         sec = time_unclassed$sec
@@ -302,17 +302,17 @@ g.plot5 = function(metadatadir=c(),dofirstpage=FALSE, viewingwindow = 1,f0=c(),f
         S$sib.onset.time = iso8601chartime2POSIX(S$sib.onset.time, tz = desiredtz)
         S$sib.end.time = iso8601chartime2POSIX(S$sib.end.time, tz = desiredtz)
         def = unique(S$definition)[1]
-        S = S[which(S$definition==def),] # simplify to one definition
+        S = S[which(S$definition == def),] # simplify to one definition
         for (j in 1:max(unique(S$night))) { #nights #length(unique(S$night)
-          tmp = S[which(S$night==j),]
+          tmp = S[which(S$night == j),]
           for (h in 1:nrow(tmp)) { # sleep periods
-            s0 = which(time == as.character(tmp$sib.onset.time[h]))[1]
-            s1 = which(time == as.character(tmp$sib.end.time[h]))[1]
+            s0 = which(time == format(tmp$sib.onset.time[h]))[1]
+            s1 = which(time == format(tmp$sib.end.time[h]))[1]
             if (length(s0) == 0 | is.na(s0) == TRUE) {
-              s0 = which(time == paste(as.character(tmp$sib.onset.time[h])," 00:00:00",sep=""))[1]
+              s0 = which(time == paste(format(tmp$sib.onset.time[h])," 00:00:00",sep = ""))[1]
             }
             if (length(s1) == 0 | is.na(s1) == TRUE) {
-              s1 = which(time == paste(as.character(tmp$sib.end.time[h])," 00:00:00",sep=""))[1]
+              s1 = which(time == paste(format(tmp$sib.end.time[h]), " 00:00:00", sep = ""))[1]
             }
             if (is.na(s0) == FALSE & is.na(s1) == FALSE) { #new on 18 May 2015
               detection[s0:s1] = 1 #new on 18 May 2015
